# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without maven
%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/%{base_name}/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define base_name       collections
%define short_name      commons-%{base_name}
%define section         free

Name:           apache-%{short_name}
Version:        3.2.1
Release:        6%{?dist}
Epoch:          0
Summary:        Apache Commons Collections Package
License:        ASL 2.0
Group:          Development/Libraries/Java
Url:            http://commons.apache.org/collections
Source0:        http://www.apache.org/dist/jakarta/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Source3:        %{name}-component-info.xml
Source4:        collections-tomcat5-build.xml
Patch0:         %{name}-javadoc-nonet.patch

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7
BuildRequires:  ant-junit
BuildRequires:  junit >= 0:3.8.1
%if %with maven
BuildRequires:  apache-commons-parent >= 0:12
BuildRequires:  maven-plugin-bundle
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-assembly
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-idea
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
%endif
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       java >= 0:1.6.0
Requires:       jpackage-utils
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot
Provides:       jakarta-%{short_name} = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{epoch}:%{version}-%{release}
Provides:       %{short_name} = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name} < %{epoch}:%{version}-%{release}

%description
The introduction of the Collections API by Sun in JDK 1.2 has been a
boon to quick and effective Java programming. Ready access to powerful
data structures has accelerated development by reducing the need for
custom container classes around each core object. Most Java2 APIs are
significantly easier to use because of the Collections API.
However, there are certain holes left unfilled by Sun's
implementations, and the Jakarta-Commons Collections Component strives
to fulfill them. Among the features of this package are:
- special-purpose implementations of Lists and Maps for fast access
- adapter classes from Java1-style containers (arrays, enumerations) to
Java2-style collections.
- methods to test or create typical set-theory properties of collections
such as union, intersection, and closure.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java
Provides:       jakarta-%{short_name}-repolib = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-repolib < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-repolib = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-repolib < %{epoch}:%{version}-%{release}

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%package testframework
Summary:        Testframework for %{name}
Group:          Development/Testing
Requires:       %{name} = %{epoch}:%{version}-%{release}
Provides:       jakarta-%{short_name}-testframework = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-testframework < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-testframework = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-testframework < %{epoch}:%{version}-%{release}
%if %{gcj_support}
Requires(post):         java-gcj-compat
Requires(postun):       java-gcj-compat
%endif

%description testframework
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Provides:       jakarta-%{short_name}-javadoc = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-javadoc < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-javadoc = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-javadoc < %{epoch}:%{version}-%{release}
Requires:       jpackage-utils

%description javadoc
%{summary}.

%package tomcat5
Summary:        Collection dependency for Tomcat5
Group:          Development/Libraries/Java
Provides:       jakarta-%{short_name}-tomcat5 = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-tomcat5 < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-tomcat5 = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-tomcat5 < %{epoch}:%{version}-%{release}

%description tomcat5
Collections dependency for Tomcat5

%package testframework-javadoc
Summary:        Javadoc for %{name}-testframework
Group:          Development/Documentation
Provides:       jakarta-%{short_name}-testframework-javadoc = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-testframework-javadoc < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-testframework-javadoc = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-testframework-javadoc < %{epoch}:%{version}-%{release}

%description testframework-javadoc
%{summary}.

%if %with maven
%package manual
Summary:        Documents for %{name}
Group:          Development/Documentation
Provides:       jakarta-%{short_name}-manual = %{epoch}:%{version}-%{release}
Obsoletes:      jakarta-%{short_name}-manual < %{epoch}:%{version}-%{release}
Provides:       %{short_name}-manual = %{epoch}:%{version}-%{release}
Obsoletes:      %{short_name}-manual < %{epoch}:%{version}-%{release}

%description manual
%{summary}.
%endif

%prep
%setup -q -n %{short_name}-%{version}-src
# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;

%patch0 -p1 -b .sav0

cp %{SOURCE4} .

cp -p %{SOURCE1} settings.xml

%if %with maven
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" settings.xml

mkdir external_repo
ln -s %{_javadir} external_repo/JPP
%endif


%build
%if %with maven
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Dproject.build.directory=$(pwd)/target"
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        install javadoc:javadoc
ant tf.javadoc
%else
#FIXME Enabling tests with gcj causes memory leaks!
# See http://gcc.gnu.org/bugzilla/show_bug.cgi?id=28423
%if %{gcj_support}
%{ant} -Djava.io.tmpdir=. jar javadoc tf.validate tf.jar dist.bin dist.src tf.javadoc
%else
%{ant} -Djava.io.tmpdir=. test dist tf.javadoc
%endif
%endif

# commons-collections-tomcat5
%{ant} -f collections-tomcat5-build.xml

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
%if %with maven
install -p -m 644 target/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
install -p -m 644 target/%{short_name}-testframework-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-testframework-%{version}.jar
%else
install -p -m 644 build/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
install -p -m 644 build/%{short_name}-testframework-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-testframework-%{version}.jar
%endif

#tomcat5
install -p -m 644 collections-tomcat5/%{short_name}-tomcat5.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-tomcat5-%{version}.jar

%add_to_maven_depmap %{short_name} %{short_name} %{version} JPP %{short_name}
%add_to_maven_depmap org.apache.commons %{short_name} %{version} JPP %{short_name}
%add_to_maven_depmap %{short_name} %{short_name}-testframework %{version} JPP %{short_name}-testframework
%add_to_maven_depmap org.apache.commons %{short_name}-testframework %{version} JPP %{short_name}-testframework

ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}.jar
ln -s %{name}-testframework-%{version}.jar %{buildroot}%{_javadir}/%{name}-testframework.jar
ln -s %{name}-testframework-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-testframework-%{version}.jar
ln -s %{name}-testframework-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-testframework.jar
ln -s %{name}-testframework-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-testframework-%{version}.jar
ln -s %{name}-testframework-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-testframework.jar
ln -s %{name}-tomcat5-%{version}.jar %{buildroot}%{_javadir}/%{name}-tomcat5.jar
ln -s %{name}-tomcat5-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-tomcat5-%{version}.jar
ln -s %{name}-tomcat5-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-tomcat5.jar
ln -s %{name}-tomcat5-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-tomcat5-%{version}.jar
ln -s %{name}-tomcat5-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-tomcat5.jar


# pom
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -p -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{short_name}.pom

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%if %with maven
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -p *.txt target/site
cp -p *.html target/site
%else
cp -pr build/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%endif
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/jakarta-%{short_name}-%{version}
ln -s jakarta-%{short_name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/jakarta-%{short_name}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{short_name}-%{version}
ln -s %{short_name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{short_name}

# testframework-javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-testframework-%{version}
cp -pr build/docs/testframework/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-testframework-%{version}
ln -s %{name}-testframework-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}-testframework
ln -s %{name}-testframework-%{version} $RPM_BUILD_ROOT%{_javadocdir}/jakarta-%{short_name}-testframework-%{version}
ln -s jakarta-%{short_name}-testframework-%{version} $RPM_BUILD_ROOT%{_javadocdir}/jakarta-%{short_name}-testframework
ln -s %{name}-testframework-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{short_name}-testframework-%{version}
ln -s %{short_name}-testframework-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{short_name}-testframework

# manual
%if %with maven
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr target/site/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
rm -r $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/apidocs
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_docdir}/jakarta-%{short_name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_docdir}/%{short_name}-%{version}
%endif

%if %with repolib
%{__install} -d -m 0755 %{buildroot}%{repodir}
%{__install} -d -m 0755 %{buildroot}%{repodirlib}
%{__install} -p -m 0644 %{SOURCE3} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__install} -d -m 0755 %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE0} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE2} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/%{short_name}.jar
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%if %{gcj_support}
%post testframework
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%if %{gcj_support}
%postun testframework
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%if %{gcj_support}
%post tomcat5
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%if %{gcj_support}
%postun tomcat5 
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc PROPOSAL.html README.txt LICENSE.txt RELEASE-NOTES.html
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_javadir}/%{short_name}.jar
%{_javadir}/jakarta-%{short_name}-%{version}.jar
%{_javadir}/jakarta-%{short_name}.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-*%{version}.jar.*
%endif

%files testframework
%defattr(0644,root,root,0755)
%{_javadir}/%{name}-testframework-%{version}.jar
%{_javadir}/%{name}-testframework.jar
%{_javadir}/%{short_name}-testframework-%{version}.jar
%{_javadir}/%{short_name}-testframework.jar
%{_javadir}/jakarta-%{short_name}-testframework-%{version}.jar
%{_javadir}/jakarta-%{short_name}-testframework.jar
%if %{gcj_support}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-testframework-%{version}.jar.*
%endif

%files tomcat5
%defattr(0644,root,root,0755)
%{_javadir}/*-tomcat5*.jar
%if %{gcj_support}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*-tomcat5*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}
%{_javadocdir}/jakarta-%{short_name}-%{version}
%{_javadocdir}/jakarta-%{short_name}
%{_javadocdir}/%{short_name}-%{version}
%{_javadocdir}/%{short_name}

%files testframework-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-testframework-%{version}
%{_javadocdir}/%{name}-testframework
%{_javadocdir}/jakarta-%{short_name}-testframework-%{version}
%{_javadocdir}/jakarta-%{short_name}-testframework
%{_javadocdir}/%{short_name}-testframework-%{version}
%{_javadocdir}/%{short_name}-testframework

%if %with maven
%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}
%{_docdir}/jakarta-%{short_name}-%{version}
%{_docdir}/%{short_name}-%{version}
%endif

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Wed Feb 02 2011 David Walluck <dwalluck@redhat.com> 0:3.2.1-6
- provide compat symlinks for javadoc and manual
- fix symlink logic
- fix apidocs removal during %%install
- update License to match Fedora standard

* Thu Dec 09 2010 Ralph Apel <r.apel@r-apel.de> 0:3.2.1-5
- Fix compat symlinks for jakarta-commons-collections

* Thu Oct 07 2010 Ralph Apel <r.apel@r-apel.de> 0:3.2.1-4
- Provide compat symlinks for jakarta-commons-collections

* Tue Sep 21 2010 David Walluck <dwalluck@redhat.com> 0:3.2.1-3
- drop Requires: apache-commons-parent (brings in maven2 at runtime)

* Wed Sep 08 2010 Ralph Apel <r.apel at r-apel.de> 0:3.2.1-2
- OK move it to free

* Wed Nov 18 2009 Ralph Apel <r.apel at r-apel.de> 0:3.2.1-1
- 3.2.1
- rename to apache-commons-collections
- drop maven1 build
- build with maven2 by default
- add repolib subpackage

* Tue Apr 07 2009 Ralph Apel <r.apel at r-apel.de> 0:3.2-3.jpp6
- First JPP-6 release

* Mon Nov 19 2007 Ralph Apel <r.apel at r-apel.de> 0:3.2-2jpp
- Fix depmap fragment

* Mon Aug 13 2007 Ralph Apel <r.apel at r-apel.de> 0:3.2-1jpp
- Upgrade to 3.2
- Add pom and depmap frag
- Make Vendor, Distribution based on macro

* Fri May 11 2007 Jason Corley <jason.corley@gmail.com> 0:3.1-11jpp
- rebuild through mock and centos 4
- replace vendor and distribution with macros

* Thu May 03 2007 Ralph Apel <r.apel at r-apel.de> 0:3.1-10jpp
- Fix project_properties.patch to meet new plugins
- Silence prep section
- Restore Vendor and Distribution

* Fri Feb 23 2007 Jason Corley <jason.corley@gmail.com> 0:3.1-9jpp
- update copyright to contain current year
- rebuild on RHEL4 to avoid broken jar repack script in FC6

* Fri Jan 26 2007 Matt Wringe <mwringe@redhat.com> - 0:3.1-8jpp
- Fix bug in collections-tomcat5-build.xml

* Fri Jan 19 2007 Matt Wringe <mwringe@redhat.com> - 0:3.1-7jpp
- Add tomcat5 subpackage
- Add versioning to provides and obsoletes
- Move rm -rf %%RPM_BUILD_ROOT from %%prep to %%install
- Add missing maven dependencies

* Fri Aug 04 2006 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.1-6jpp
- Add proper Requires(x) statements where appropriate.

* Thu Jul 20 2006 Vivek Lakshmanan <vivekl@redhat.com> - 0:3.1-5jpp
- Remove duplicate NVR define statements.

* Mon Jul 17 2006 Vivek Lakshmanan <vivekl at redhat.com> - 0:3.1-4jpp
- Add conditional native compilation.
- Update commons-collections-3.1-project_xml.patch to exclude reference
  to maven-plugin-changelog which requires netbeans-svc etc.
- Set test.failonerror to false and add patch for build.xml for ant builds
  with gcj to avoid stopping the build on test failures on GCJ.

* Fri Apr 07 2006 Ralph Apel <r.apel at r-apel.de> - 0:3.1-3jpp
- First JPP-1.7 release
- Activate tests
- Activate testframework and add -testframework subpackages
- Add -manual subpackage
- Build with maven by default
- Optionally build with straight ant

* Wed May 25 2005 Gary Benson <gbenson at redhat.com> - 0:3.1-2jpp
- Do not fetch stuff from sun.com during javadoc generation.
- Add build dependency on ant-junit.

* Thu Sep 16 2004 Ralph Apel <r.apel at r-apel.de> - 0:3.1-1jpp
- Upgrade to 3.1

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:2.1.1-2jpp
- Rebuild with ant-1.6.2

* Sun Jun 27 2004 Kaj J. Niemi <kajtzu@fi.basen.net> 0:2.1.1-1jpp
- Update to 2.1.1

* Fri May 09 2003 David Walluck <david@anti-microsoft.org> 0:2.1-4jpp
- update for JPackage 1.5

* Fri Mar 21 2003 Nicolas Mailhot <Nicolas.Mailhot (at) JPackage.org > 2.1-3jpp
- For jpackage-utils 1.5

* Thu Feb 27 2003 Henri Gomez <hgomez@users.sourceforge.net> 2.1-2jpp
- fix ASF license and add package tag

* Thu Oct 24 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.1-1jpp
- 2.1
- remove build patch about Java APIS link

* Fri Jul 12 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0-4jpp
- override java.io.tmpdir to avoid build use /tmp

* Mon Jun 10 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0-3jpp
- use sed instead of bash 2.x extension in link area to make spec compatible 
  with distro using bash 1.1x

* Fri Jun 07 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0-2jpp
- added short names in %%{_javadir}, as does jakarta developpers 

* Mon May 06 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.0-1jpp 
- 2.0
- distribution tag
- group tag
- regenerated patch

* Sat Jan 19 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-5jpp
- renamed to %%{name}
- additional sources in individual archives
- versioned dir for javadoc
- section macro

* Fri Dec 7 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-4jpp
- javadoc into javadoc package

* Sat Nov 3 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-3jpp
- used original summary
- added missing license

* Sat Oct 13 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-2jpp
- first unified release
- used web page description
- s/jPackage/JPackage

* Mon Aug 27 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-1mdk
- first Mandrake release
